/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.ipgeocoder.servlet;

import com.liferay.ipgeocoder.messaging.IPGeocoderMessageListener;
import com.liferay.portal.kernel.messaging.Destination;
import com.liferay.portal.kernel.messaging.DestinationNames;
import com.liferay.portal.kernel.messaging.MessageBusUtil;
import com.liferay.portal.kernel.messaging.MessageListener;
import com.liferay.portal.kernel.messaging.ParallelDestination;
import com.liferay.portal.kernel.util.BasePortalLifecycle;

import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;

/**
 * @author Brian Wing Shun Chan
 */
public class IPGeocoderServletContextListener
	extends BasePortalLifecycle implements ServletContextListener {

	public void contextDestroyed(ServletContextEvent servletContextEvent) {
		portalDestroy();
	}

	public void contextInitialized(ServletContextEvent servletContextEvent) {
		registerPortalLifecycle();
	}

	@Override
	protected void doPortalDestroy() {
		_ipGeocoderDestination.unregister(_ipGeocoderMessageListener);

		MessageBusUtil.removeDestination(
			_ipGeocoderDestination.getName());

		MessageBusUtil.removeDestination(DestinationNames.IP_GEOCODER_RESPONSE);
	}

	@Override
	protected void doPortalInit() {
		_ipGeocoderDestination = new ParallelDestination(
			DestinationNames.IP_GEOCODER);

		MessageBusUtil.addDestination(_ipGeocoderDestination);

		_ipGeocoderMessageListener = new IPGeocoderMessageListener();

		_ipGeocoderDestination.register(_ipGeocoderMessageListener);

		Destination ipGeocoderResponseDestination = new ParallelDestination(
			DestinationNames.IP_GEOCODER_RESPONSE);

		MessageBusUtil.addDestination(ipGeocoderResponseDestination);
	}

	private Destination _ipGeocoderDestination;
	private MessageListener _ipGeocoderMessageListener;

}