/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.ipgeocoder.util;

import com.liferay.ipgeocoder.model.IPInfo;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.util.portlet.PortletProps;

import com.maxmind.geoip.Location;
import com.maxmind.geoip.LookupService;

import java.io.IOException;

/**
 * @author Brian Wing Shun Chan
 */
public class IPGeocoderUtil {

	public static IPInfo getIPInfo(String ipAddress) {
		return _instance._getIPInfo(ipAddress);
	}

	private IPGeocoderUtil() {
		_init();
	}

	private void _init() {
		try {
			if (_lookupService == null) {
				_lookupService = new LookupService(
					PortletProps.get("maxmind.database.file"),
					LookupService.GEOIP_MEMORY_CACHE);
			}
		}
		catch (IOException ioe) {
			_log.error(ioe.getMessage());
		}
	}

	private IPInfo _getIPInfo(String ipAddress) {
		_init();

		if (_lookupService != null) {
			Location location = _lookupService.getLocation(ipAddress);

			return new IPInfo(ipAddress, location);
		}
		else {
			return null;
		}
	}

	private static Log _log = LogFactoryUtil.getLog(IPGeocoderUtil.class);

	private static IPGeocoderUtil _instance = new IPGeocoderUtil();

	private LookupService _lookupService;

}